﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using System.Collections;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Session["EmployeeData"] == null)
            Session["EmployeeData"] = GetEmployees();

        WebDataGrid1.DataSource = Session["EmployeeData"];
    }

    #region Helper Methods
    /// <summary>
    /// This is a function that will take all the values from RowUpdating and apply them
    /// back to a row in the DataTable that is used as the DataSource of our grid
    /// </summary>
    /// <param name="values">All the values for a row</param>
    /// <param name="dt">The DataSource of the Grid</param>
    private void UpdateTableRow(Hashtable values, DataTable dt)
    {
        int id = (int)values[dt.PrimaryKey[0].ColumnName];
        DataRow updatingRow = dt.Rows.Find(id);

        foreach (object key in values.Keys)
            updatingRow[key.ToString()] = values[key] == null ? DBNull.Value : values[key];
    }
    #endregion

    #region Sample Data
    private DataTable GetEmployees()
    {
        return this.GetEmployees(24);
    }

    private DataTable GetEmployees(int count)
    {
        DataTable dtData = new DataTable("Employees");

        dtData.Columns.Add("EmployeeID", typeof(int));
        dtData.Columns.Add("Name", typeof(string));
        dtData.Columns.Add("OnSite", typeof(bool));
        dtData.Columns.Add("DateOfHire", typeof(DateTime));
        dtData.Columns.Add("Department", typeof(int));
        dtData.Columns.Add("Site", typeof(string));


        for (int i = 0; i < count; i++)
        {
            dtData.Rows.Add(new object[] { i, string.Format("Name {0}", i), (i % 2 == 0), DateTime.Today.Date.AddDays(-1 * i), i % 8, "http://www.google.com" });
        }

        dtData.PrimaryKey = new DataColumn[] { dtData.Columns["EmployeeID"] };

        return dtData;
    }
    #endregion

    protected void WebDataGrid1_RowUpdating(object sender, Infragistics.Web.UI.GridControls.RowUpdatingEventArgs e)
    {
        if (Session["EmployeeData"] != null)
        {
            DataTable dt = Session["EmployeeData"] as DataTable;

            UpdateTableRow(e.Values, dt);
        }
    }
}